=======
Credits
=======

Development Leads
----------------

* Caleb Lareau <caleblareau@g.harvard.edu>
* Jacob Ulirsch <julirsch@g.harvard.edu>

Supervisors
---------------

* Martin Aryee
* Jason Buenrostro
* Vijay Sankaran

Contributors
------------

* Leif Ludwig
